function [ x,dx,de,dde,T,dT,N_T,dN_T,N,dN ] = read_realdata_cyl( file )
% Read in data from datafile of with 15 headerlines, and rows like the following:
% x [cm], y [cm], h1 [cm], h2 [cm], de [cm], di [cm], T [min], T [sek], 
% N_T [counts]
%
% Explanation of the datafile rows:
%  x     distance from detector(bor) side to moderator top side
%  y     distance from detector(bor) side to right side of moderator
%  h1    distance from detector(bor) bottom to moderator surface
%        if zero, it was not possible to measure because of geometry
%  h2    distance from detector(bor) top to detector top
%  de    depht of hole
%  di    maximum diameter of hole (tried to keep this one constant)
%  T     time counted (split into minutes and seconds below)
%  N_T   number of counts
% 
% Explanation of output variables:
%  x     x-value (position along measuring axis)
%  dx    uncertainty of the x-value
%  de    depht of hole
%  dde   uncertainty in the hole depth
%  T     counting time
%  dT    uncertainty of the time
%  N_T   count number during time T
%  dN_T  uncertainty of the count number
%  N     intensity calculated in units of cpm
%  dN    uncertainty of the intensity

% Read in data
fprintf(['Reading in data from datafile ',file,'.dat...\n'])
fid  = fopen([file,'.dat']);  
data = cell2mat(textscan(fid,'%n %n %n %n %n %n %n %n %n','headerlines',15));
fclose(fid);      

% Save the relevant variables
x    = data(:,1)+2.555;                            %position on measuring axis
de   = data(:,5);                                  %depth of hole
T    = data(:,7) + data(:,8)/60;                   %time measured
N_T  = data(:,9);                                  %number of counts

% Calculate uncertainties
dx   = 1/10*ones(1,length(x));                     %assumed from the measurements
dde  = zeros(1,length(de));                        %assumed to be irrelevant
dT   = zeros(1,length(T));                         %assumed to be irrelevant
dN_T = sqrt(N_T);                                  %Poisson distributed numbers

% Calculate intensity in counts per minute
N    = N_T ./ T;
dN   = dN_T ./ T;

end

