function [ x,dx,T,dT,N_T,dN_T,N,dN ] = read_realdata_wh( file )
% Read in data from datafile of with 13 headerlines, and rows like the following:
% x [cm], y [cm], h1 [cm], h2 [cm], T [min], T [sek], N_T [counts]
%
% This function is like read_realdata, but does calculate detector and boron 
% plast height, along with uncertainties.
%
% Explanation of the datafile rows:
%  x     distance from detector(bor) side to moderator top side
%  y     distance from detector(bor) side to right side of moderator
%  h1    distance from detector(bor) bottom to moderator surface
%        if zero, it was not possible to measure because of geometry
%  h2    distance from detector(bor) top to detector top
%  T     time counted (split into minutes and seconds below)
%  N_T   number of counts
% 
% Explanation of output variables:
%  x     x-value (position along measuring axis)
%  dx    uncertainty of the x-value
%  T     counting time
%  dT    uncertainty of the time
%  N_T   count number during time T
%  dN_T  uncertainty of the count number
%  N     intensity calculated in units of cpm
%  dN    uncertainty of the intensity

% Read in data
fprintf(['Reading in data from datafile ',file,'.dat...\n'])
fid  = fopen([file,'.dat']);      
data = cell2mat(textscan(fid,'%n %n %n %n %n %n %n','headerlines',13)); 
fclose(fid);

% Save the relevant variables
x    = data(:,1) + 2.555;                   %position on measuring axis
T    = data(:,5) + data(:,6)/60;            %time measured
N_T  = data(:,7);                           %number of counts

% Calculate uncertainties
dx   = 1/10*ones(1,length(x));              %assumed from the measurements
dT   = zeros(1,length(T));                  %assumed to be irrelevant
dN_T = sqrt(N_T);                           %Poisson distributed numbers

% Calculate intensity in counts per minute
N    = N_T ./ T;
dN   = dN_T ./ T;

% Pick out all actual measured height data
h1t  = data(:,3);                           %height from surface to bor
h2t  = data(:,4);                           %height from detector top to bor
dh1t = ones(1,length(h1t))*0.05;            %uncertainty from reading nonius
dh2t = ones(1,length(h1t))*0.05;            %uncertainty from reading nonius
k = 0;
for i = 1:length(h1t)
    if (h1t(i) > 0)                         %use only actual measured data
        k = k + 1;
        h1(k) = h1t(i);
        h2(k) = h2t(i);
        dh1(k) = dh1t(i);
        dh2(k) = dh2t(i);
    end
end

% Calculate the average height of the detector 
housing    = ones(1,length(h1))*18.7;       %length of bor housing
dhousing   = ones(1,length(h1))*0.05;       %uncertainty from reading nonius
detectorL  = ones(1,length(h1))*12.75;      %length of detector
ddetectorL = ones(1,length(h1))*0.05;       %uncertainty from reading nonius
height     = h1 + housing - detectorL - h2;
dheight    = sqrt(dh1.^2 + dhousing.^2 + ddetectorL.^2 + dh2.^2);
avgheight  = sum(height)/length(height);
%davgheight= 1/length(height)*sqrt(sum(dheight.^2));
davgheight = (max(height)-min(height))/2;
fprintf(['  The average height of the detector over the surface is:  ',...
         num2str(avgheight),' +/- ',num2str(davgheight),' cm\n'])
fprintf(['    so the average height of the detector over the bottom ',...
         'surface is:  ',num2str(10*(avgheight+6.8)),' mm\n'])

% Calculate the average height of the bor plast
avgh1      = sum(h1)/length(h1);
%davgh1    = 1/length(h1)*sqrt(sum(dh1.^2));
davgh1     = (max(h1)-min(h1))/2;
fprintf(['  The average height of the bor plast over the surface is:  ',...
         num2str(avgh1),' +/- ',num2str(davgh1),' cm\n'])
fprintf(['    so the average height of the bor plast over the bottom ',...
         'surface is:  ',num2str(10*(avgh1+6.8)),' mm\n\n'])

end